@@ -6,7 +6,7 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '2.000';
+our $VERSION = '2.001';
 
 use Clone           qw( clone );
 use List::MoreUtils qw( first_index );
@@ -165,9 +165,9 @@ sub __prepare_col_func {
     }
     elsif ( $func eq 'Truncate' ) {
         my $info = "TRUNC $qt_col";
-        my $name = "Decimal places:";
+        my $name = "Decimal places: ";
         my $precision = choose_a_number( 2,
-            { info => $info, name => $name, small_on_top => 1, mouse => $sf->{o}{table}{mouse}, clear_screen => 0 }
+            { info => $info, name => $name, small => 1, mouse => $sf->{o}{table}{mouse}, clear_screen => 0 }
         );
         return if ! defined $precision;
         $quote_f = $obj_db->truncate( $qt_col, $precision );
